Enumeration
GntColorType
Members
-
GNT_COLOR_NORMAL -
The normal widget background color.
- Value:
1 - Available since: 3.0
- Value:
-
GNT_COLOR_HIGHLIGHT -
The widget background color for highlighting, e.g., when a button is selected.
- Value:
2 - Available since: 3.0
- Value:
-
GNT_COLOR_DISABLED -
The background color for disabled widgets.
- Value:
3 - Available since: 3.0
- Value:
-
GNT_COLOR_HIGHLIGHT_D -
The color for selected widgets, in windows without focus.
- Value:
4 - Available since: 3.0
- Value:
-
GNT_COLOR_TEXT_NORMAL -
The color of text in an entry.
- Value:
5 - Available since: 3.0
- Value:
-
GNT_COLOR_TEXT_INACTIVE -
The color of text when the entry is out of focus.
- Value:
6 - Available since: 3.0
- Value:
-
GNT_COLOR_MNEMONIC -
The color of a mnemonic character. Unused.
- Value:
7 - Available since: 3.0
- Value:
-
GNT_COLOR_MNEMONIC_D -
The color of a mnemonic character for a widget without focus. Unused.
- Value:
8 - Available since: 3.0
- Value:
-
GNT_COLOR_SHADOW -
The color of a widget shadow.
- Value:
9 - Available since: 3.0
- Value:
-
GNT_COLOR_TITLE -
The color of the title of a window or box.
- Value:
10 - Available since: 3.0
- Value:
-
GNT_COLOR_TITLE_D -
The color of the title of a window or box that is out of focus.
- Value:
11 - Available since: 3.0
- Value:
-
GNT_COLOR_URGENT -
This is for the ‘urgent’ windows.
- Value:
12 - Available since: 3.0
- Value:
-
GNT_COLORS -
A count of the number of colors. Custom color types start from this value.
- Value:
13 - Available since: 3.0
- Value: