Enumeration

GntMenuType

Declaration

enum Gnt.MenuType

Description [src]

A toplevel-menu is displayed at the top of the screen, and it spans across the entire width of the screen. A popup-menu could be displayed, for example, as a context menu for widgets.

Members

GNT_MENU_TOPLEVEL

Menu for a toplevel window.

  • Value: 1
  • Available since: 3.0
GNT_MENU_POPUP

A popup menu.

  • Value: 2
  • Available since: 3.0