API Version: 3.0
Library Version: 3.0.0-dev0
Generated by gi-docgen 2025.3
enum Gnt.MenuType
A toplevel-menu is displayed at the top of the screen, and it spans across the entire width of the screen. A popup-menu could be displayed, for example, as a context menu for widgets.
GNT_MENU_TOPLEVEL
Menu for a toplevel window.
1
GNT_MENU_POPUP
A popup menu.
2
Content